Exception: NXT::Exceptions::CommandError
- Inherits:
-
RuntimeError
- Object
- RuntimeError
- NXT::Exceptions::CommandError
- Defined in:
- lib/nxt/exceptions.rb
Overview
Raised when a command returns a reply message error
Raised when a command returns a reply message error